abacusai.vector_store — AbacusAI documentation

# `abacusai.vector_store`

## Module Contents

### Classes

`VectorStore` | A vector store that stores embeddings for a list of document trunks.

class abacusai.vector_store.VectorStore(client, name=None, vectorStoreId=None, createdAt=None, latestVectorStoreVersion={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A vector store that stores embeddings for a list of document trunks.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The name of the vector store.

    - vectorStoreId (str) – The unique identifier of the vector store.

    - createdAt (str) – When the vector store was created.

    - latestVectorStoreVersion (VectorStoreVersion) – The latest version of vector store.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  wait_until_ready(timeout=3600)

    A waiting call until vector store is ready.

    Parameters:

      timeout (int, optional) – The waiting time given to the call to finish, if it doesn’t finish by the allocated time, the call is said to be timed out. Default value given is 3600 seconds.

  get_status()

    Gets the status of the vector store.

    Returns:

      A string describing the status of a vector store (pending, complete, etc.).

    Return type:

      str